==> haskell-wai-middleware-static-0.8.2-70-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-middleware-static
version: 0.8.2
id: wai-middleware-static-0.8.2-2hsK0D78Ck3K7CJgtdap0r
key: wai-middleware-static-0.8.2-2hsK0D78Ck3K7CJgtdap0r
license: BSD-3-Clause
copyright: (c) 2012-2014 Andrew Farmer
maintainer: Andrew Farmer <afarmer@ittc.ku.edu>
author: Andrew Farmer <afarmer@ittc.ku.edu>
stability: experimental
homepage: https://github.com/scotty-web/wai-middleware-static
synopsis: WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.
    .
    [WAI] <http://hackage.haskell.org/package/wai>
category: Web
abi: 85db66595303963b565636562c66ab48
exposed: True
exposed-modules:
    Network.Wai.Middleware.Static
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-middleware-static-0.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-middleware-static-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-middleware-static-0.8.2
hs-libraries: HSwai-middleware-static-0.8.2-2hsK0D78Ck3K7CJgtdap0r
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf directory-1.3.3.0
    expiring-cache-map-0.0.6.1-FTJZWmDHnJI1UBk0W9OttL filepath-1.4.2.1
    http-types-0.12.3-LIupN3s0vqzJPmAPHPcGbD
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk mtl-2.2.2
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78 text-1.2.3.1 time-1.8.0.2
    wai-3.2.2-FKI9I9MeRyhBwlVDOn737X
haddock-interfaces: /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock
haddock-html: /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-middleware-static-0.8.2-71-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-middleware-static
version: 0.8.2
id: wai-middleware-static-0.8.2-1wzPfHVOpXxG5dtpNKdppV
key: wai-middleware-static-0.8.2-1wzPfHVOpXxG5dtpNKdppV
license: BSD-3-Clause
copyright: (c) 2012-2014 Andrew Farmer
maintainer: Andrew Farmer <afarmer@ittc.ku.edu>
author: Andrew Farmer <afarmer@ittc.ku.edu>
stability: experimental
homepage: https://github.com/scotty-web/wai-middleware-static
synopsis: WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.
    .
    [WAI] <http://hackage.haskell.org/package/wai>
category: Web
abi: de4a18472a12f9951affe727eb6660df
exposed: True
exposed-modules:
    Network.Wai.Middleware.Static
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-middleware-static-0.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-middleware-static-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-middleware-static-0.8.2
hs-libraries: HSwai-middleware-static-0.8.2-1wzPfHVOpXxG5dtpNKdppV
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf directory-1.3.3.0
    expiring-cache-map-0.0.6.1-4bhz5U68295CYD82Y8pWDa filepath-1.4.2.1
    http-types-0.12.3-1S9CCheq0oP9PZghw2BQoa
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk mtl-2.2.2
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78 text-1.2.3.1 time-1.8.0.2
    wai-3.2.2-JhiHpDUxHXaFTRuLDNcWjT
haddock-interfaces: /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock
haddock-html: /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
